import { Injectable, UnauthorizedException } from '@nestjs/common';
import { TicketDataService } from '../data/services/ticket.service';
import { QueueOrder } from './entities/order.entity';
import { title } from 'process';

@Injectable()
export class QueueOrchestrator {
  constructor(private readonly dataService: TicketDataService) {}

  async loginCustomer(id: string): Promise<QueueOrder> {
    try {
      return await this.dataService.loginQueue(id);
    } catch (error) {
      throw new UnauthorizedException({
        message: 'Invoice tidak ditemukan',
        error: 'INVOICE_NOT_FOUND',
      });
    }
  }

  async queueTickets(order_id: string): Promise<any> {
    const tickets = await this.dataService.queueTickets(order_id);
    const items = tickets[0].items;
    return items.map((item) => {
      return {
        id: item.id,
        title: item.item.name,
        qty: item.qty,
        available: true,
        average: 12,
        nearest: '13:10',
        crowded_level: 20,
        available_time: '15:00',
      };
    });
  }
}
