import {
  Body,
  Controller,
  Get,
  Param,
  Patch,
  Post,
  Put,
  Res,
} from '@nestjs/common';

import { MODULE_NAME } from 'src/core/strings/constants/module.constants';
import { ApiBearerAuth, ApiTags } from '@nestjs/swagger';

import { Public } from 'src/core/guards';
import { QueueOrchestrator } from '../../domain/queue.orchestrator';
import { QueueOrder } from '../../domain/entities/order.entity';

@ApiTags(`Queue`)
@Controller(`v1/${MODULE_NAME.QUEUE}`)
@Public(true)
@ApiBearerAuth('JWT')
export class QueueController {
  constructor(private orchestrator: QueueOrchestrator) {}

  @Get('login/:id')
  async loginCustomer(@Param('id') id: string): Promise<QueueOrder> {
    return await this.orchestrator.loginCustomer(id);
  }

  @Get('tickets/:id')
  async queueTickets(@Param('id') id: string): Promise<void> {
    return await this.orchestrator.queueTickets(id);
  }
}
